==> libopenshot-audio-docs-0.3.2-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/search/variables_7.js <==
var searchData=
[
  ['identifier_0',['identifier',['../structjuce_1_1MidiDeviceInfo.html#afb78c8d5e34af5590dde609cf207b353',1,'juce::MidiDeviceInfo']]],
  ['ignorecaseofkeynames_1',['ignoreCaseOfKeyNames',['../structjuce_1_1PropertiesFile_1_1Options.html#ad91a81a1d472cfbaa1b394282c81f669',1,'juce::PropertiesFile::Options']]],
  ['initialnote_2',['initialNote',['../structjuce_1_1MPENote.html#aa6b88078f19cacd8a5313c434e468178',1,'juce::MPENote']]],
  ['initialtimbre_3',['initialTimbre',['../structjuce_1_1MPENote.html#ab54231c0ad8a4415e5d65da249638e66',1,'juce::MPENote']]],
  ['input_4',['input',['../classjuce_1_1AudioFormatReader.html#a06f90bc088c17a8468a14b5725baea4a',1,'juce::AudioFormatReader']]],
  ['inputchannels_5',['inputChannels',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#ab6afc44a81a6bcb02fe43727b22a1c76',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['inputdevicename_6',['inputDeviceName',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#a5ed36c301d7e07481bb331efda3d2a7c',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['insertedtext_7',['insertedText',['../structjuce_1_1TextDiff_1_1Change.html#a8f41a80cb68f107a8f68ea52cec5181f',1,'juce::TextDiff::Change']]],
  ['instanceid_8',['instanceID',['../structjuce_1_1NetworkServiceDiscovery.html#a565d0faa51ea0c7a87b25002a9a6dbc9',1,'juce::NetworkServiceDiscovery::Service']]],
  ['instrument_9',['instrument',['../structjuce_1_1MPESynthesiserBase.html#aa433dfa54bda9c8878bc4b194c108b32',1,'juce::MPESynthesiserBase']]],
  ['interval_10',['interval',['../classjuce_1_1NormalisableRange.html#aba17035293537390b75cdaa429093a5f',1,'juce::NormalisableRange']]],
  ['is14bitvalue_11',['is14BitValue',['../structjuce_1_1MidiRPNMessage.html#a98cebd192db533fd90fbd61cc7e403d2',1,'juce::MidiRPNMessage']]],
  ['isbypassed_12',['isBypassed',['../structjuce_1_1dsp_1_1ProcessContextReplacing.html#ab330cb2e7b8920ab90eeb7852a4b4038',1,'juce::dsp::ProcessContextReplacing::isBypassed()'],['../structjuce_1_1dsp_1_1ProcessContextNonReplacing.html#ade7142ebfa4246066e103f0f1d432019',1,'juce::dsp::ProcessContextNonReplacing::isBypassed()']]],
  ['islooping_13',['isLooping',['../structjuce_1_1AudioPlayHead_1_1CurrentPositionInfo.html#a98c11a68e79549ae8c281812cdee2515',1,'juce::AudioPlayHead::CurrentPositionInfo']]],
  ['isnrpn_14',['isNRPN',['../structjuce_1_1MidiRPNMessage.html#a6ece38f0979ab2351cd8140c0f55bc89',1,'juce::MidiRPNMessage']]],
  ['isplaying_15',['isPlaying',['../structjuce_1_1AudioPlayHead_1_1CurrentPositionInfo.html#a75eee50183b880ecb7beb1798a15aa34',1,'juce::AudioPlayHead::CurrentPositionInfo']]],
  ['isrc_16',['ISRC',['../classjuce_1_1WavAudioFormat.html#a53627f3fa6179ef279e8688bc25b2704',1,'juce::WavAudioFormat']]],
  ['isrecording_17',['isRecording',['../structjuce_1_1AudioPlayHead_1_1CurrentPositionInfo.html#ad7e6357482c8ed16c3969c9b84ba0c8d',1,'juce::AudioPlayHead::CurrentPositionInfo']]],
  ['issymboliclink_18',['isSymbolicLink',['../classjuce_1_1ZipFile.html#a821bbad9fda78c68847796e35167a94c',1,'juce::ZipFile::ZipEntry']]]
];

==> libopenshot-audio-docs-0.3.3-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/search/variables_7.js <==
var searchData=
[
  ['identifier_0',['identifier',['../structjuce_1_1MidiDeviceInfo.html#afb78c8d5e34af5590dde609cf207b353',1,'juce::MidiDeviceInfo']]],
  ['ignorecaseofkeynames_1',['ignoreCaseOfKeyNames',['../structjuce_1_1PropertiesFile_1_1Options.html#ad91a81a1d472cfbaa1b394282c81f669',1,'juce::PropertiesFile::Options']]],
  ['initialnote_2',['initialNote',['../structjuce_1_1MPENote.html#aa6b88078f19cacd8a5313c434e468178',1,'juce::MPENote']]],
  ['initialtimbre_3',['initialTimbre',['../structjuce_1_1MPENote.html#ab54231c0ad8a4415e5d65da249638e66',1,'juce::MPENote']]],
  ['input_4',['input',['../classjuce_1_1AudioFormatReader.html#a06f90bc088c17a8468a14b5725baea4a',1,'juce::AudioFormatReader']]],
  ['inputchannels_5',['inputChannels',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#ab6afc44a81a6bcb02fe43727b22a1c76',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['inputdevicename_6',['inputDeviceName',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#a5ed36c301d7e07481bb331efda3d2a7c',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['insertedtext_7',['insertedText',['../structjuce_1_1TextDiff_1_1Change.html#a8f41a80cb68f107a8f68ea52cec5181f',1,'juce::TextDiff::Change']]],
  ['instanceid_8',['instanceID',['../structjuce_1_1NetworkServiceDiscovery.html#a565d0faa51ea0c7a87b25002a9a6dbc9',1,'juce::NetworkServiceDiscovery::Service']]],
  ['instrument_9',['instrument',['../structjuce_1_1MPESynthesiserBase.html#aa433dfa54bda9c8878bc4b194c108b32',1,'juce::MPESynthesiserBase']]],
  ['interval_10',['interval',['../classjuce_1_1NormalisableRange.html#aba17035293537390b75cdaa429093a5f',1,'juce::NormalisableRange']]],
  ['is14bitvalue_11',['is14BitValue',['../structjuce_1_1MidiRPNMessage.html#a98cebd192db533fd90fbd61cc7e403d2',1,'juce::MidiRPNMessage']]],
  ['isbypassed_12',['isBypassed',['../structjuce_1_1dsp_1_1ProcessContextReplacing.html#ab330cb2e7b8920ab90eeb7852a4b4038',1,'juce::dsp::ProcessContextReplacing::isBypassed'],['../structjuce_1_1dsp_1_1ProcessContextNonReplacing.html#ade7142ebfa4246066e103f0f1d432019',1,'juce::dsp::ProcessContextNonReplacing::isBypassed']]],
  ['islooping_13',['isLooping',['../structjuce_1_1AudioPlayHead_1_1CurrentPositionInfo.html#a98c11a68e79549ae8c281812cdee2515',1,'juce::AudioPlayHead::CurrentPositionInfo']]],
  ['isnrpn_14',['isNRPN',['../structjuce_1_1MidiRPNMessage.html#a6ece38f0979ab2351cd8140c0f55bc89',1,'juce::MidiRPNMessage']]],
  ['isplaying_15',['isPlaying',['../structjuce_1_1AudioPlayHead_1_1CurrentPositionInfo.html#a75eee50183b880ecb7beb1798a15aa34',1,'juce::AudioPlayHead::CurrentPositionInfo']]],
  ['isrc_16',['ISRC',['../classjuce_1_1WavAudioFormat.html#a53627f3fa6179ef279e8688bc25b2704',1,'juce::WavAudioFormat']]],
  ['isrecording_17',['isRecording',['../structjuce_1_1AudioPlayHead_1_1CurrentPositionInfo.html#ad7e6357482c8ed16c3969c9b84ba0c8d',1,'juce::AudioPlayHead::CurrentPositionInfo']]],
  ['issymboliclink_18',['isSymbolicLink',['../classjuce_1_1ZipFile.html#a821bbad9fda78c68847796e35167a94c',1,'juce::ZipFile::ZipEntry']]]
];
